@@ -1,7 +1,8 @@
 package PDF::Imposition::Schema2side;
 use strict;
 use warnings;
-use base "PDF::Imposition::Schema";
+use Moo;
+with 'PDF::Imposition::Schema';
 
 =head1 NAME
 
@@ -68,10 +69,34 @@ sub _do_impose {
         $chunk = $self->get_imported_page(shift(@pages));
         $gfx->formimage($chunk, $self->orig_width, 0) if $chunk;
     }
-    $self->out_pdf_obj->saveas($self->outfile);
-    return $self->outfile;
 }
 
+=head1 INTERNALS
+
+=head2 pages_per_sheet
+
+Returns 4
+
+=head2 cropmarks_options
+
+Set outer to false and force signature to 4.
+
+=cut
+
+
+sub cropmarks_options {
+    my %options = (
+                   top => 1,
+                   bottom => 1,
+                   inner => 1,
+                   outer => 0,
+                   twoside => 1,
+                   signature => 4,
+                  );
+    return %options;
+}
+
+sub pages_per_sheet { 4 };
 
 1;
 
