@@ -1,7 +1,8 @@
 package PDF::Imposition::Schema2x4x2;
 use strict;
 use warnings;
-use base qw/PDF::Imposition::Schema/;
+use Moo;
+with 'PDF::Imposition::Schema';
 
 =head1 NAME
 
@@ -78,9 +79,6 @@ sub _do_impose {
         $self->_compose_quadruple($p14, $p3, $p6, $p11);
         $self->_compose_quadruple($p4, $p13, $p12, $p5);
     }
-    
-    $self->out_pdf_obj->saveas($self->outfile);
-    return $self->outfile;
 }
 
 sub _compose_quadruple {
@@ -109,6 +107,33 @@ sub _compose_quadruple {
     $gfx->formimage($chunk, $self->orig_width, 0) if $chunk;
 }
 
+=head1 INTERNALS
+
+=head2 pages_per_sheet
+
+Returns 8
+
+=head2 cropmarks_options
+
+Set inner to false and force signature to 16.
+
+=cut
+
+
+sub cropmarks_options {
+    my %options = (
+                   top => 1,
+                   bottom => 1,
+                   inner => 0,
+                   outer => 1,
+                   twoside => 1,
+                   signature => 16,
+                  );
+    return %options;
+}
+
+sub pages_per_sheet { 8 };
+
 1;
 
 =head1 SEE ALSO
